def get_versions():
    return versions[0]["number"]


versions = [
    {
        "number": "0.0.2",
        "features": [
            "Debug Setup.py error",
        ],
    },
    {
        "number": "0.0.1",
        "features": [
            "Separate miRNABlast from the original Genome_work_tools",
        ],
    },
]